/*****************************************************************************
*
* Atmel Corporation
*
* File              : USI_TWI_Slave.h
* Compiler          : IAR EWAAVR 2.28a/3.10a
* Revision          : $Revision: 1.7 $
* Date              : $Date: 26. mai 2004 11:35:34 $
* Updated by        : $Author: ltwa $
*
* Support mail      : avr@atmel.com
*
* Supported devices : All device with USI module can be used.
*                     The example is written for the ATmega169, ATtiny26 & ATtiny2313
*
* AppNote           : AVR312 - Using the USI module as a TWI slave
*
* Description       : Header file for USI_TWI driver
*
* Changes for WinAVR by Frank Jonischkies, fjonisch@gmx.de, 11.08.2005
*
****************************************************************************/

// Defines controlling code generation
//#define BUFFER_CONTROL

#define TWI_RX_BUFFER_SIZE 6     
#define TWI_TX_BUFFER_SIZE 6

#define TRUE                1
#define FALSE               0

#define BUFFER_CONTROL

//********** USI_TWI Prototypes **********//

void          USI_TWI_Slave_Initialise( unsigned char );
unsigned char USI_TWI_Start_Transceiver_With_Data( unsigned char *,unsigned char );
unsigned char USI_TWI_Get_Data_From_Transceiver( unsigned char *,unsigned char );


// Device dependant defines
#if defined (__AVR_ATmega169__)
#define DDR_USI             DDRE
#define PORT_USI            PORTE
#define PIN_USI             PINE
#define PORT_USI_SDA        PORTE5
#define PORT_USI_SCL        PORTE4
#define PIN_USI_SDA         PINE5
#define PIN_USI_SCL         PINE4

#elif defined (__AVR_ATtiny26__)
#define DDR_USI             DDRB
#define PORT_USI            PORTB
#define PIN_USI             PINB
#define PORT_USI_SDA        PORTB0
#define PORT_USI_SCL        PORTB2
#define PIN_USI_SDA         PINB0
#define PIN_USI_SCL         PINB2

#elif defined (__AVR_ATtiny2313__)
#define DDR_USI             DDRB
#define PORT_USI            PORTB
#define PIN_USI             PINB
#define PORT_USI_SDA        PB5
#define PORT_USI_SCL        PB7
#define PIN_USI_SDA         PINB5
#define PIN_USI_SCL         PINB7

#else
#warning "device type not defined"
#endif

//********** Global Variables **********//

union USI_TWI_statusReg                       // Status byte holding flags.
{
    unsigned char all;
    struct
    {
        unsigned char dataInTxBuf:1;
        unsigned char dataInRxBuf:1;
        unsigned char genAddressCall:1;                        // TRUE = General call, FALSE = TWI Address;
        unsigned char RxBufOverflow:1;
        unsigned char TxBufOverflow:1;
        unsigned char unused:3;
    };
};

extern union USI_TWI_statusReg USI_TWI_statusReg;

