/*****************************************************************************
*
* Atmel Corporation
*
* File              : USI_TWI_Slave.c
* Compiler          : IAR EWAAVR 2.28a/3.10a
* Revision          : $Revision: 1.7 $
* Date              : $Date: 26. mai 2004 11:35:34 $
* Updated by        : $Author: ltwa $
*
* Support mail      : avr@atmel.com
*
* Supported devices : All device with USI module can be used.
*                     The example is written for the ATmega169, ATtiny26 & ATtiny2313
*
* AppNote           : AVR312 - Using the USI module as a TWI slave
*
* Description       : Example showing how to use the USI_TWI drivers;
*                     Loops back received data.
*
* Changes for WinAVR by Frank Jonischkies, fjonisch@gmx.de, 11.08.2005
*
****************************************************************************/

#include <avr/io.h>
#include <avr/interrupt.h>
#include "USI_TWI_Slave.h"

#define MESSAGEBUF_SIZE       4

// Sample TWI transmission commands
#define TWI_CMD_MASTER_WRITE 0x10
#define TWI_CMD_MASTER_READ  0x20

int main( void )
{    
  unsigned char messageBuf[MESSAGEBUF_SIZE], TWI_slaveAddress;

  // LED feedback port - connect port B to the STK500 LEDS
  DDRD  = 0xFF; // Set to ouput
  PORTD = 0x55; // Startup pattern
	OSCCAL = 0x47; // Wert mit Programiergert auslesen und hier einsetzen!
  // Own TWI slave address
  TWI_slaveAddress = 0x10;				// Das ist die 7 Bit Adresse! mit dem R/W bit also: (0x10<<1) = 0x20
  USI_TWI_Slave_Initialise( TWI_slaveAddress );

  sei();                          
        

  // This example is made to work together with the AVR310 USI TWI Master application note. In adition to connecting the TWI
  // pins, also connect PORTB to the LEDS. The code reads a message as a TWI slave and acts according to if it is a 
  // general call, or an address call. If it is an address call, then the first byte is considered a command byte and
  // it then responds differently according to the commands.

  // This loop runs forever. If the TWI Transceiver is busy the execution will just continue doing other operations.
  for(;;)
  {    
// Check if the last operation was a reception
    if ( USI_TWI_statusReg.dataInRxBuf )
    {
      USI_TWI_Get_Data_From_Transceiver(messageBuf, 2);         
// Check if the last operation was a reception as General Call        
      if ( USI_TWI_statusReg.genAddressCall )
      {
      // Put data received out to PORTB as an example.        
        PORTB = messageBuf[0];                              
      }
// Ends up here if the last operation was a reception as Slave Address Match                  
      else
      {
// Example of how to interpret a command and respond.
      // TWI_CMD_MASTER_WRITE stores the data to PORTB
        if (messageBuf[0] == TWI_CMD_MASTER_WRITE)
          PORTD = messageBuf[1];                            
      // TWI_CMD_MASTER_READ prepares the data from PINB in the transceiver buffer for the TWI master to fetch.
        if (messageBuf[0] == TWI_CMD_MASTER_READ)
        {
          messageBuf[0] = PIND;                             
          USI_TWI_Start_Transceiver_With_Data( messageBuf, 1 );           
        }
      }
    }
    
    // Do something else while waiting for the TWI transceiver to complete.    
    // Put own code here.
  }
}
